<?php
/*
 * Battle was developed for SMF forums c/o SA, nend & Chen Zhen
 * Copyright 2022  SA | nend | Chen Zhen
 * Revamped and supported by Chen Zhen
 * This software package is distributed under the terms of its Creative Commons - Attribution No Derivatives License (by-nd) 3.0
 * License: https://creativecommons.org/licenses/by-nd/3.0/
 * Support thread: https://web-develop.ca/index.php?board=15.0
 */

if (!defined('SMF'))
	die('Hacking attempt...');

function battleAdmin()
{
	global $context, $sourcedir, $modSettings, $txt;

	//Set title and default sub-action.
	loadTemplate('Battle_Admin');

	//Load the language strings
	loadLanguage('Battle');

	//Are you allowed to administrate Battle?
	if (!allowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	require_once($sourcedir . '/BattleAdminQuests.php');
	require_once($sourcedir . '/Subs-BattleAdmin.php');

	if (empty($context['current_page']))
		$context['current_page'] = 1;

	$context['page_title'] = $txt['battle_adminmmc'];
        $context['current_page'] = (!empty($_REQUEST['current_page']) ? (int)$_REQUEST['current_page'] : $context['current_page']) -1;
	$context[$context['admin_menu_name']]['tab_data']['title'] = $txt['battle_adminmm'];
	$context[$context['admin_menu_name']]['tab_data']['description'] = $txt['battle_adminmmd'];
	$context['battle_sort'] = (!empty($_REQUEST['sort'])) && $_REQUEST['sort'] === 'id_member' ? 'id_member;' : 'real_name;';
	$context['battle_order'] = (!empty($_REQUEST['order'])) && $_REQUEST['order'] === 'DESC' ? 'DESC;' : 'ASC;';
	$context['battle_reset_points'] = isset($_REQUEST['battle_reset_points']) ? (int)$_REQUEST['battle_reset_points'] : 0;
	$context['battle_delete_imagedirs'] = isset($_REQUEST['battle_delete_imagedirs']) ? (int)$_REQUEST['battle_delete_imagedirs'] : 0;
	$context['battle_smf_version'] = version_compare((!empty($modSettings['smfVersion']) ? substr($modSettings['smfVersion'], 0, 3) : '2.0'), '2.1', '<') ? 'v2.0' : 'v2.1';

	$subActions = array(
		'main' => 'battle_main',
		'config' => 'battle_settings',
		'campaigns' => 'battle_campaigns',
		'edit_campaign' => 'battle_campaign_edit',
		'save_campaign' => 'battle_campaign_edit',
		'del_campaign' => 'battle_campaign_delete',
		'add_campaign' => 'battle_campaign_add',
		'prune_campaign' => 'battle_campaign_prune',
		'shop' => 'battle_shops',
		'add_item' => 'battle_shop_add_edit',
		'edit_item' => 'battle_shop_add_edit',
		'save_item' => 'battle_shop_add_edit',
		'shop_del' => 'battle_shop_item_delete',
		'bmem' => 'battle_members',
		'monsterlist' => 'battle_monsterlist',
		'editm' => 'battle_monster',
		'monster' => 'battle_monster',
		'savemonster' => 'battle_monster',
		'del' => 'battle_monster_delete',
		'quest_edit' => 'battle_quest_add_edit',
		'quest_save' => 'battle_quest_add_edit',
		'quest_add' => 'battle_quest_add_edit',
		'quest' => 'battle_quests',
		'quest_del' => 'battle_quest_delete',
		'custom' => 'battle_custom',
		'custom_del' => 'battle_cust_delete',
		'custom_edit' => 'battle_cust_add_edit',
		'custom_save' => 'battle_cust_add_edit',
		'custom_add' => 'battle_cust_add_edit',
		'maintain' => 'battle_maintain',
		'reset' => 'battle_reset',
		'resetgame' => 'battle_reset_game',
		'dshout' => 'battle_reset_shouts',
		'dhist' => 'battle_reset_hist',
		'dlead' => 'battle_reset_leaderboard',
		'dquest' => 'battle_reset_quest',
		'dpoints' => 'battle_reset_points',
		'bigint' => 'battle_fix_currency',
		'cimages' => 'battle_transfer_images',
		'manage_upload' => 'battle_manage_upload',
		'image_upload' => 'battle_images_upload',
		'image_delete' => 'battle_images_delete'
	);



	$_REQUEST['sa'] = isset($_REQUEST['sa']) && isset($subActions[$_REQUEST['sa']]) ? $_REQUEST['sa'] : 'main';
	$subActions[$_REQUEST['sa']]();
}

function battle_main()
{
	// Connect to https://web-develop.ca via socket for new messages concerning this modification
	global $context, $txt, $sourcedir;
	if (!AllowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	require_once($sourcedir . '/Subs-Package.php');

	list($url, $download, $message, $version, $downloadTitle, $downloadText) = array('https://web-develop.ca/index.php?page=battle_news', 'https://web-develop.ca/index.php?action=downloads;area=stable_battle_rpg', $txt['battle_news_connect'], '??', $txt['battle_mod_dlbattle'], $txt['battle_mod_dlbattlemod']);
	$html = fetch_web_data($url) ? fetch_web_data($url) : false;

	if ($html)
	{
		if (strpos(trim($html), '<div id="news_battle"') !== false)
		{
			$dom = new DOMDocument();
			libxml_use_internal_errors(true);
			$dom->loadHTML($html);
			libxml_use_internal_errors(false);
			$vers = $dom->getElementById('battle_version');
			$link = $dom->getElementById('battle_download');
			$linkTitle = $dom->getElementById('battle_download_title');
			$linkText = $dom->getElementById('battle_download_txt');
			$download = !empty($link->nodeValue) ? $link->nodeValue : 'https://web-develop.ca/index.php?action=downloads;area=stable_battle_rpg';
			$downloadTitle = !empty($linkTitle->nodeValue) ? $linkTitle->nodeValue : $txt['battle_mod_dlbattle'];
			$downloadText = !empty($linkText->nodeValue) ? $linkText->nodeValue : $txt['battle_mod_dlbattlemod'];
			$version = !empty($vers->nodeValue) ? $vers->nodeValue : '??';
			$element = $dom->getElementById('news_battle');
			$message = !empty($element->nodeValue) ? $element->nodeValue : $txt['battle_news_connect'];
		}
	}

	$context['battle_news_connect'] = str_replace(array("\r\n", "\n", "\r"), '<br />', $message) . '<div style="padding-left: 1em;"><a title="' . $downloadTitle . '" href="' . $download . '" target="_blank">' . $downloadText . '</a></div>';
	$context['battle_version_connect'] = $version;
}

function battle_maintain()
{
	global $txt, $context;
	if (!allowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	$context['battle_mcommands'] = array('resetgame' => 'breset', 'reset' => 'breset', 'dquest' => 'breset', 'dpoints' => 'breset', 'dshout' => 'empty', 'dhist' => 'empty', 'dlead' => 'empty', 'bigint' => 'bigintchange', 'cimages' => 'imagedirscopy');

	foreach ($context['battle_mcommands'] as $key => $command)
		$context['battle_maintain_' . $key] = !empty($_REQUEST[$key]) ? $_REQUEST[$key] : false;

	$context['html_headers'] .= '
	<script type="text/javascript">
		function battle_maintenance_extra() {
			var battleDpointsLink = document.getElementById("linkdpoints");
			var battleDpointsReset = document.getElementById("battle_reset_points");
			var battleCimagesLink = document.getElementById("linkcimages");
			var battleCimagesDel = document.getElementById("battle_delete_imagedirs");
			if (battleDpointsLink && battleDpointsReset && battleDpointsReset.checked)
				battleDpointsLink.href += ";battle_reset_points=1";
			if (battleCimagesLink && battleCimagesDel && battleCimagesDel.checked)
				battleCimagesLink.href += ";battle_delete_imagedirs=1";
		}
		if (window.addEventListener)
			window.addEventListener("load", function (){
				battle_maintenance_extra();
				return false;
			});
		else
			window.attachEvent("onload", function (){
				battle_maintenance_extra();
				return false;
			});
	</script>';
	$context['sub_template'] = 'maintain';
	$context['page_title'] = $txt['battle_tabaman'];
}

function battle_custom()
{
	global $context, $txt, $smcFunc, $scripturl;
	if (!AllowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	$context['page_title'] = 'Custom Actions';
	$context['sub_template'] = 'battle_custom';
	$context['battle_diaplay'] = array('page' => false, 'pages' => '0');
	$context['battle_custom'] = array();
	$request = $smcFunc['db_query']('', '
			SELECT id_explore, start
			FROM {db_prefix}battle_explore
			ORDER BY id_explore DESC'
		);

	// Loop through all results
	// And add them to the list
	while ($row = $smcFunc['db_fetch_assoc']($request))
		$context['battle_custom'][] = array(
			'id_explore' => $row['id_explore'],
			'start' => $row['start']
		);

	$smcFunc['db_free_result']($request);

	$context['battle_cust'] = battle_pagination($context['battle_custom'], 10);
	$context['battle_display'] = battle_pages($txt['battle_page'], false, $scripturl . '?action=admin;area=battle;sa=custom;', $context['current_pages']);
}

function battle_monster()
{
	global $smcFunc, $context, $txt;
	if (!AllowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	$context['monster']['id'] = !empty($_REQUEST['monster']) ? (int) $_REQUEST['monster'] : 0;
	$context['battle_images'] = getImageList('monsters');

	if (!empty($_POST['submit']))
	{
		checkSession();
		$fields = array('atk', 'def', 'name', 'hp', 'img', 'max_hp', 'mon_range', 'mon_max_range', 'evolve', 'counter');
		foreach ($fields as $field)
		{
			if ($field === 'counter' || $field === 'evolve' || $field === 'mon_range')
				$_POST[$field] = !empty($_POST[$field]) ? (int)$_POST[$field] : 0;
			elseif (empty($_POST[$field]))
				fatal_error($field . ' ' . $txt['battle_Quest_error1'], false);
			else
			{
				if ($field === 'counter')
					$_POST[$field] = !empty($context['monster']['counter']) ? (int)$context['monster']['counter'] : 0;

				if ($field === 'evolve')
					$_POST[$field] = (int)$_POST[$field] > 1000 ? 1000 : (int)$_POST[$field];

				if ($field !== 'name' && $field !== 'img')
					$_POST[$field] = abs($_POST[$field]);
				else
					$_POST[$field] = $smcFunc['htmlspecialchars']($_POST[$field], ENT_QUOTES);

			}
		}

		if (empty($context['monster']['id']))
		{
			$smcFunc['db_insert']('',
				'{db_prefix}battle_monsters',
				array('atk' => 'int', 'def' => 'int', 'name' => 'string', 'hp' => 'int', 'img' => 'string', 'max_hp' => 'int', 'mon_range' => 'int', 'mon_max_range' => 'int', 'evolve' => 'int', 'counter' => 'int'),
				array($_POST['atk'], $_POST['def'], $_POST['name'], $_POST['hp'], $_POST['img'], $_POST['max_hp'], $_POST['mon_range'], $_POST['mon_max_range'], $_POST['evolve'], $_POST['counter']),
				array('id_monster')
			);
		}
		else
		{
			$smcFunc['db_insert']('replace', '{db_prefix}battle_monsters',
				array(
					'id_monster' => 'int',
					'name' => 'string',
					'atk' => 'int',
					'def' => 'int',
					'hp' => 'int',
					'img' => 'string',
					'max_hp' => 'int',
					'mon_range' => 'int',
					'mon_max_range' => 'int',
					'evolve' => 'int',
					'counter' => 'int'
				),
				array(
					$context['monster']['id'],
					$_POST['name'],
					$_POST['atk'],
					$_POST['def'],
					$_POST['hp'],
					$_POST['img'],
					$_POST['max_hp'],
					$_POST['mon_range'],
					$_POST['mon_max_range'],
					$_POST['evolve'],
					$_POST['counter']
				),
				array('id_monster')
			);

		}

		redirectexit('action=admin;area=battle;sa=monsterlist');
	}

	if (!empty($context['monster']['id']))
	{
		$request = $smcFunc['db_query']('', '
			SELECT name, atk, def, hp, img, max_hp, mon_range, mon_max_range, evolve, counter
			FROM {db_prefix}battle_monsters
			WHERE id_monster = {int:id_monster}',
			array('id_monster' => $context['monster']['id'],)
		);

		while ($row = $smcFunc['db_fetch_assoc']($request))
		{
			$context['monster'] += array(
				'name' => $row['name'],
				'atk' => $row['atk'],
				'def' => $row['def'],
				'hp' => $row['hp'],
				'img' => $row['img'],
				'max_hp' => $row['max_hp'],
				'mon_range' => $row['mon_range'],
				'mon_max_range' => $row['mon_max_range'],
				'evolve' => $row['evolve'],
				'counter' => !empty($row['counter']) ? (int)$row['counter'] : 0
			);
		}

		$smcFunc['db_free_result']($request);
	}
	else
	{
		$context['monster'] += array(
			'name' => '',
			'atk' => '',
			'def' => '',
			'hp' => '',
			'img' => '',
			'max_hp' => '',
			'mon_range' => '',
			'mon_max_range' => '',
			'evolve' => '',
			'counter' => ''
		);
	}

	$context['sub_template'] = 'monsterEdit_Add';
	$context['page_title'] = $txt['battle_monsters'];
}

function battle_monsterlist()
{
	global $smcFunc, $scripturl, $txt, $request, $context;

	$context['sub_template'] = 'battle_admin_monsters';
	$context['page_title'] = $txt['battle_monsters'];
	$context['battle_diaplay'] = array('page' => false, 'pages' => '0');
	$output = array();

	// Get the data.
	$request = $smcFunc['db_query']('', '
		SELECT id_monster, atk, def, hp, name, img, max_hp, mon_range, mon_max_range, evolve, counter
		FROM {db_prefix}battle_monsters
		ORDER BY atk DESC'
		);

	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$output[] = array(
			'id_monster' => $row['id_monster'],
			'name' => $row['name'],
			'atk' => $row['atk'],
			'def' => $row['def'],
			'hp' => $row['hp'],
			'img' => $row['img'],
			'max_hp' => $row['max_hp'],
			'mon_range' => $row['mon_range'],
			'mon_max_range' => $row['mon_max_range'],
			'evolve' => $row['evolve'],
			'counter' => !empty($row['counter']) ? $row['counter'] : 0
			);


	}

	$smcFunc['db_free_result']($request);

	$context['get_monsters'] = battle_pagination($output, 10);
	$context['battle_display'] = battle_pages($txt['battle_page'], false, $scripturl . '?action=admin;area=battle;sa=monsterlist;', $context['current_pages']);
}

function battle_shops($per_page = 10)
{
	global $smcFunc, $scripturl, $txt, $context;

	if (!AllowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	$context['sub_template'] = 'battle_shop';
	$context['page_title'] = $txt['battle_shop_item'];
	$context['shop'] = array();
	$context['battle_diaplay'] = array('page' => false, 'pages' => '0');
	$page = $context['current_page'] * $per_page;

	$request = $smcFunc['db_query']('', '
		SELECT COUNT(id_item) FROM {db_prefix}battle_shop
		WHERE id_item');

	$row = $smcFunc['db_fetch_assoc']($request);
	$smcFunc['db_free_result']($request);
	$tempArray = array_values($row);
	$nRows = array_shift($tempArray);

	$battleQ = $smcFunc['db_query']('', '
			SELECT id_item, name, price, action, img, description, amount
			FROM {db_prefix}battle_shop
			LIMIT {int:page}, {int:per}',
			array(
				'page' => $page,
				'per' => $per_page,
			)
		);

		// And add them to the list
		while ($row = $smcFunc['db_fetch_assoc']($battleQ))
			$context['shop'][] = array(
				'id_item' => $row['id_item'],
				'name' => $row['name'],
				'price' => $row['price'],
				'action' => $row['action'],
				'img' => $row['img'],
				'amount' => $row['amount'],
				'description' => $row['description'],
			);

	$smcFunc['db_free_result']($battleQ);

	// $context['shop'] = battle_pagination($context['battle_shop'], 10);
	$context['current_pages'] = (($nRows-1) / $per_page) + 1;
	$context['battle_display'] = battle_pages($txt['battle_page'], false, $scripturl . '?action=admin;area=battle;sa=shop;', $context['current_pages']);
}

function battle_settings($return_config = false)
{
	global $txt, $scripturl, $context, $sourcedir, $modSettings, $smcFunc;

	if (!allowedTo('admin_battle'))
		fatal_error($txt['battle_admin_error1'], false);

	require_once($sourcedir.'/ManageServer.php');
	$currency = !empty($modSettings['bcash']) ? $modSettings['bcash'] : 'gold';
	db_extend('packages');

	// Additional settings added with JavaScript
	$txtData = array('confirmCopy' => $txt['battle_confirm_copy_currency'], 'confirmAdd' => $txt['battle_confirm_add_currency'],'confirmDel' => $txt['battle_confirm_del_currency'], 'alertDel' => $txt['battle_alert_del_currency']);
	$context['html_headers'] .= '
	<script type="text/javascript">
		function checkbattleCurrencyInput(battleCurrencyInputX) {
			if (battleCurrencyInputX.value == "' . $currency . '") {
				document.getElementById("battle_add_currency").value = "0";
				document.getElementById("battle_add_currency").checked = false;
				document.getElementById("battle_del_currency").value = "0";
				document.getElementById("battle_del_currency").checked = false;
				document.getElementById("battle_copy_currency").value = "0";
				document.getElementById("battle_copy_currency").checked = false;
			}
		}
		function newBattleCheckboxClick(idx) {
			var battleCurrency = "' . $currency . '";
			var newBattleBoxData = [], battleBoxDatum = ' . json_encode($txtData) . ';
			var battleCurrencyInput = document.getElementById("bcash");
			battleCurrencyInput.onchange = function(){checkbattleCurrencyInput(this);};
			for (var keyName in battleBoxDatum) {
				newBattleBoxData[keyName] = battleBoxDatum[keyName].replace("<br />", "\r\n").replace("<br>", "\r\n").replace("<br/>", "\r\n");
			}
			if (battleCurrencyInput.value == "' . $currency . '") {
				document.getElementById("battle_add_currency").value = "0";
				document.getElementById("battle_add_currency").checked = false;
				document.getElementById("battle_del_currency").value = "0";
				document.getElementById("battle_del_currency").checked = false;
				document.getElementById("battle_copy_currency").value = "0";
				document.getElementById("battle_copy_currency").checked = false;
			}
			else if (idx.value == 0) {
				if (idx.id == "battle_copy_currency")
					var confirmIdx = confirm(newBattleBoxData.confirmCopy);
				else if (idx.id == "battle_add_currency")
					var confirmIdx = confirm(newBattleBoxData.confirmAdd);
				else if (battleCurrency != "gold")
					var confirmIdx = confirm(newBattleBoxData.confirmDel);
				else {
					var confirmIdx = false;
					alert(newBattleBoxData.alertDel);
				}
				if (confirmIdx == true) {
					if (idx.id == "battle_copy_currency") {
						document.getElementById("battle_add_currency").value = "0";
						document.getElementById("battle_add_currency").checked = false;
					}
					else if (idx.id == "battle_add_currency") {
						document.getElementById("battle_copy_currency").value = "0";
						document.getElementById("battle_copy_currency").checked = false;
					}
					idx.value = 1;
					idx.checked = true;
				}
				else {
					idx.value = 0;
					idx.checked = false;
				}
			}
			else {
				idx.value = 0;
			}
		}
		function battle_add_checkboxes() {
			var addBattleForm = document.getElementsByClassName("settings");
			var newBattleDT = document.createElement("DT");
			newBattleDT.className = "centertext";
			newBattleDT.style ="position: relative;font-weight:bold;font-size:10px;vertical-align:middle;";
			var newBattleDD = document.createElement("DD");
			newBattleDD.style ="position: relative;font-weight:bold;font-size:10px;vertical-align:middle;";
			var newBattleCheck1 = document.createElement("INPUT");
			newBattleCheck1.type = "checkbox";
			newBattleCheck1.id = "battle_copy_currency";
			newBattleCheck1.name = "battle_copy_currency";
			newBattleCheck1.value = "0";
			newBattleCheck1.style="vertical-align: middle;position: relative;transform: scale(1.2);";
			newBattleCheck1.onclick = function(){newBattleCheckboxClick(this);};
			var newBattleCheck2 = document.createElement("INPUT");
			newBattleCheck2.type = "checkbox";
			newBattleCheck2.id ="battle_del_currency";
			newBattleCheck2.name ="battle_del_currency";
			newBattleCheck2.value = "0";
			newBattleCheck2.style="vertical-align: middle;position: relative;transform: scale(1.2);";
			newBattleCheck2.onclick = function(){newBattleCheckboxClick(this);};
			var newBattleCheck3 = document.createElement("INPUT");
			newBattleCheck3.type = "checkbox";
			newBattleCheck3.id ="battle_add_currency";
			newBattleCheck3.name ="battle_add_currency";
			newBattleCheck3.value = "0";
			newBattleCheck3.style="vertical-align: middle;position: relative;transform: scale(1.2);";
			newBattleCheck3.onclick = function(){newBattleCheckboxClick(this);};
			var addBattleSpan1 = document.createElement("SPAN");
			addBattleSpan1.style = "vertical-align: middle;padding-left: 0.5em;";
			addBattleSpan1.innerHTML = "' . $txt['battle_maintain_copy_currency'] . '";
			var addBattleSpan2 = document.createElement("SPAN");
			addBattleSpan2.style = "vertical-align: middle;padding-left: 0.5em;";
			addBattleSpan2.innerHTML = "' . $txt['battle_maintain_del_currency'] . '";
			var addBattleSpan3 = document.createElement("SPAN");
			addBattleSpan3.style = "vertical-align: middle;padding-left: 0.5em;";
			addBattleSpan3.innerHTML = "' . $txt['battle_maintain_add_currency'] . '";
			var addBattleSpanPaddingLeft = document.createElement("SPAN");
			addBattleSpanPaddingLeft.style = "vertical-align: middle;padding-left: 2em;";
			addBattleSpanPaddingLeft.innerHTML = " ";
			newBattleDT.appendChild(newBattleCheck1);
			newBattleDT.appendChild(addBattleSpan1);
			newBattleDT.appendChild(addBattleSpanPaddingLeft);
			newBattleDT.appendChild(newBattleCheck3);
			newBattleDT.appendChild(addBattleSpan3);
			newBattleDD.appendChild(newBattleCheck2);
			newBattleDD.appendChild(addBattleSpan2);
			addBattleForm[3].insertBefore(newBattleDD, addBattleForm[3].children[4]);
			addBattleForm[3].insertBefore(newBattleDT, addBattleForm[3].children[4]);
		}
		function battle_admin_adjustments() {
			var battleIntWidths = [
				"battle_map_across",
				"battle_map_down",
				"exp_bef_level",
				"exp_stat_level",
				"battle_level_mem",
				"battle_mem_battle_limit",
				"battle_mem_kill_limit",
				"exp_def_mem",
				"exp_def_mon",
				"battle_time",
				"battle_add_amount",
				"battle_how_much_reviv_user",
				"battle_how_much_hp",
				"battle_gold_reg",
				"battle_hp_reg",
				"battle_hp_max_reg",
				"battle_atk_reg",
				"battle_atk_max_reg",
				"battle_def_reg",
				"battle_def_max_reg",
				"battle_energy_reg",
				"battle_energy_max_reg",
				"battle_stamina_reg",
				"battle_stamina_max_reg",
				"battle_reset_time",
				"battle_points"
			];
			for (i=0;i<battleIntWidths.length;i++) {
				document.getElementById(battleIntWidths[i]).style.width = "80px";
			}
		}
		if (window.addEventListener)
			window.addEventListener("load", function (){
				battle_add_checkboxes();
				battle_admin_adjustments();
				return false;
			});
		else
			window.attachEvent("onload", function (){
				battle_add_checkboxes();
				battle_admin_adjustments();
				return false;
			});
	</script>';

	// ensure there are no negative int values less one setting
	$intArray = array(
			'battle_map_across',
			'battle_map_down',
			'exp_bef_level',
			'exp_stat_level',
			'battle_level_mem',
			'battle_mem_battle_limit',
			'battle_mem_kill_limit',
			'exp_def_mem',
			'exp_def_mon',
			'battle_time',
			'battle_add_amount',
			'battle_how_much_reviv_user',
			'battle_how_much_hp',
			'battle_gold_reg',
			'battle_hp_reg',
			'battle_hp_max_reg',
			'battle_atk_reg',
			'battle_atk_max_reg',
			'battle_def_reg',
			'battle_def_max_reg',
			'battle_energy_reg',
			'battle_energy_max_reg',
			'battle_stamina_reg',
			'battle_stamina_max_reg',
			'battle_auto_lvl',
			'battle_players_lvl',
			'battle_reset_time',
			'battle_points'
		);

	foreach ($intArray as $int)
	{
		$modSettings[$int] = !empty($modSettings[$int]) ? $modSettings[$int] : 0;

		if ($int === 'battle_level_mem' && (!empty($modSettings['battle_level_mem']) ? (int)$modSettings['battle_level_mem'] : -1) < -1)
			$modSettings['battle_level_mem'] = -1;
		else
			$modSettings[$int] = abs($modSettings[$int]);

		$setArray[$int] = $modSettings[$int];
		updateSettings($setArray);
	}

	$context['sub_template'] = 'show_settings';

	$txt['battle_add_amount'] = sprintf($txt['battle_add_amount'],$modSettings['battle_time']);
	$config_vars = array(
		array('check', 'enable_battle', 'db', 'text'),
		array('check', 'enable_img_menu', 'db', 'text'),
		array('check', 'enable_battle_shoutbox', 'db', 'text'),
		array('check', 'enable_show_who_battle', 'db', 'text'),
		array('check', 'enable_battle_hist', 'db', 'text'),
		array('check', 'battle_enable_membattle', 'db', 'text'),
		array('check', 'battle_exp_restrict_membattle', 'db', 'text'),
		array('check', 'enable_battle_range', 'db', 'text'),
		array('check', 'enable_sts_post', 'db', 'text'),
		array('check', 'enable_sts_pm', 'db', 'text'),
		array('check', 'enable_sts_profile', 'db', 'text'),
		array('check', 'battle_auto_lvl', 'db', 'text'),
		array('check', 'battle_players_lvl', 'db', 'text'),
		array('check', 'battle_combine_pts', 'db', 'text'),
		array('select', 'battle_enable_quests', explode('|', $txt['battle_enable_quests_mode'])),
		'',
		array('int', 'battle_points', 'db', 'text'),
		array('int', 'battle_reset_time', 'db', 'text'),
		'',
		array('text', 'battle_enemy_designation', 'db', 'text'),
		array('text', 'battle_enemy_name_plural', 'db', 'text'),
		'',
		array('text', 'battle_cash', 'db', 'text'),
		array('text', 'bcash', 'db', 'text'),
		'',
		array('text', 'battle_map_name', 'db', 'text'),
		array('int', 'battle_map_across', 'db', 'text'),
		array('int', 'battle_map_down', 'db', 'text'),
		'',
		array('int', 'exp_bef_level', 'db', 'text'),
		array('int', 'exp_stat_level', 'db', 'text'),
		'',
		array('int', 'battle_level_mem', 'db', 'text'),
		array('int', 'battle_mem_battle_limit', 'db', 'text'),
		array('int', 'battle_mem_kill_limit', 'db', 'text'),
		'',
		array('int', 'exp_def_mem', 'db', 'text'),
		array('int', 'exp_def_mon', 'db', 'text'),
		'',
		array('int', 'battle_time', 'db', 'text'),
		array('int', 'battle_add_amount', 'db', 'text'),
		'',
		array('int', 'battle_how_much_reviv_user', 'db', 'text'),
		array('int', 'battle_how_much_hp', 'db', 'text'),
		'',
		array('int', 'battle_gold_reg', 'db', 'text'),
		array('int', 'battle_hp_reg', 'db', 'text'),
		array('int', 'battle_hp_max_reg', 'db', 'text'),
		array('int', 'battle_atk_reg', 'db', 'text'),
		array('int', 'battle_atk_max_reg', 'db', 'text'),
		array('int', 'battle_def_reg', 'db', 'text'),
		array('int', 'battle_def_max_reg', 'db', 'text'),
		array('int', 'battle_energy_reg', 'db', 'text'),
		array('int', 'battle_energy_max_reg', 'db', 'text'),
		array('int', 'battle_stamina_reg', 'db', 'text'),
		array('int', 'battle_stamina_max_reg', 'db', 'text'),
	);

	if (isset($_GET['save']))
	{
		if (isset($_POST['battle_enable_quests']) && $_POST['battle_enable_quests'] == 2) {
			$regIds = array(0);
			$request = $smcFunc['db_query']('', '
				SELECT min_posts, id_group
				FROM {db_prefix}membergroups
				ORDER BY id_group ASC',
				array()
			);

			while ($row = $smcFunc['db_fetch_assoc']($request))
			{
				if ($row['min_posts'] == -1)
					$regIds[] = $row['id_group'];
			}

			$smcFunc['db_free_result']($request);

			foreach ($regIds as $id) {
				$smcFunc['db_query']('', '
					DELETE FROM {db_prefix}permissions
					WHERE permission LIKE "battle_campaign_%" && id_group = {int:groupid}',
					array('groupid' => $id)
				);
			}
		}

		if (isset($_POST['bcash'])) {
			$newVal = strval($_POST['bcash']);
			$oldVal = !empty($modSettings['bcash']) ? $modSettings['bcash'] : 'gold';
			$disallowed = array(
				'id_member', 'member_name', 'date_registered', 'posts', 'id_group', 'lngfile', 'last_login', 'real_name', 'instant_messages', 'unread_messages', 'karma_bad', 'karma_good', 'notify_announcements',
				'new_pm', 'alerts', 'buddy_list', 'pm_ignore', 'pm_ignore_list', 'pm_prefs', 'mod_prefs', 'message_labels', 'passwd', 'email_address', 'personal_text', 'birthdate', 'website_title', 'website_url',
				'show_online', 'time_format', 'signature', 'time_offset', 'avatar', 'usertitle', 'member_ip', 'member_ip2', 'secret_question', 'secret_answer', 'id_theme', 'openid_uri', 'gender', 'hide_email',
				'is_activated', 'validation_code', 'id_message_last', 'additional_groups', 'smiley_set', 'id_post_group', 'total_time', 'password_salt', 'ignore_boards', 'location', 'icq', 'aim', 'yim', 'msn',
				'warning', 'passwd_flood', 'pm_receive_from', 'pm_email_notify', 'timezone', 'tfa_secret', 'tfa_backup', 'notify_regularity', 'notify_send_body', 'notify_types', 'id_msg_last_visit', 'total_time_logged_in',
				$oldVal
			);
			if (in_array($newVal, $disallowed)) {
				$_POST['bcash'] = $currency;
			}
			else {
				battle_new_currency($oldVal, $newVal);
			}
		}
		saveDBSettings($config_vars);
		redirectexit('action=admin;area=battle;sa=config');
	}

	$context['post_url'] = $scripturl .'?action=admin;area=battle;save;sa=config';
	$context['settings_title'] = $txt['battle_config'];
	prepareDBSettingContext($config_vars);
}

function battle_members($per_page = 20)
{
	global $context, $smcFunc, $b, $txt, $userid, $scripturl, $sourcedir, $user_profile, $modSettings, $user_info;

	if (!allowedTo('admin_battle'))
		redirectexit('action=battle;sa=main;home;#battle_main');

	$context['sub_template'] = 'bmembers';
	$context['page_title'] = $txt['battle_mem'];
	$context['battle_warriors'] = array();
	$context['battle_list'] = array();
	$context['battle_members'] = array();
	$context['battle_userid'] = false;
	$context['battle_diaplay'] = array('page' => false, 'pages' => '0');
	$count = 0;
	$currency = !empty($modSettings['bcash']) ? $modSettings['bcash'] : 'gold';
	$query_info = array('atk', 'max_atk', 'def', 'max_def', 'energy', 'max_energy', 'stamina', 'max_stamina', 'hp', 'max_hp', 'level', $currency);
	require_once('SSI.php');
	db_extend('packages');

	if (!empty($_REQUEST['sc']))
	{
		foreach ($query_info as $info)
			$_POST[$info] = !empty($_POST[$info]) && (int)$_POST[$info] > 0 ? (int)$_POST[$info] : 0;
	}

	if ($context['battle_order'] == 'DESC')
		$order = 'DESC';
	else
		$order = 'ASC';

	if($context['battle_sort'] == 'real_name')
		$sort = 'real_name';
	else
		$sort = 'id_member';

	require_once($sourcedir . '/Subs-Members.php');
	$allowedBattle = groupsAllowedTo('view_battle');
	$_POST['thename'] = !empty($_POST['thename']) ? $smcFunc['htmlspecialchars']($_POST['thename'], ENT_QUOTES) : '';
	if(isset($_REQUEST['next']) && isset($_REQUEST['thename']))
	{
		$userid = battle_UserId($_REQUEST['thename']);
		if(!isset($userid))
			$b['b_message'] = $txt['battle_mem_error'];
		else
		{
			loadMemberData(array($userid),false, 'normal');
			$context['battle_userlink'] = '<a href="' . $scripturl . '?action=profile;u=' . $userid . '">' . $user_profile[$userid]['real_name'] . '</a>';
			$context['battle_userid'] = ';thename=' . $userid;
			foreach ($query_info as $info)
			{
				if ($info === 'gold')
					$context['battle_warriorInfo'][$userid][$info] = battle_gold($userid);
				else
					$context['battle_warriorInfo'][$userid][$info] = battle_query($userid, $info);
			}

		}
	}

	if(isset($_REQUEST['update']))
	{
		//check the users session
		checkSession();
		$cash = !empty($_POST['cash']) ? intval($_POST['cash']) : 0;
		$atk = !empty($_POST['atk']) ? (int) $_POST['atk'] : 0;
		$def = !empty($_POST['def']) ? (int) $_POST['def'] : 0;
		$stam = !empty($_POST['stam']) ? (int) $_POST['stam'] : 0;
		$max_stam = !empty($_POST['max_stam']) ? (int) $_POST['max_stam'] : 0;
		$hp = !empty($_POST['hp']) ? (int) $_POST['hp'] : 0;
		$max_hp = !empty($_POST['max_hp']) ? (int) $_POST['max_hp'] : 0;
		$energy = !empty($_POST['energy']) ? (int) $_POST['energy'] : 0;
		$level = !empty($_POST['level']) ? (int) $_POST['level'] : 0;
		$exp = !empty($_POST['exp']) ? (int)$_POST['exp'] : 0;
		$max_exp = !empty($_POST['max_exp']) ? (int)$_POST['max_exp'] : 0;
		$max_land = !empty($_POST['max_land']) ? (int) $_POST['max_land'] : 0;
		$max_atk = !empty($_POST['max_atk']) ? (int) $_POST['max_atk'] : 0;
		$max_def = !empty($_POST['max_def']) ? (int) $_POST['max_def'] : 0;
		$max_energy = !empty($_POST['max_energy']) ? (int) $_POST['max_energy'] : 0;
		$defaults = !empty($_POST['defaults']) ? (int) $_POST['defaults'] : 0;
		$userid = !empty($_POST['thename']) ? $_POST['thename'] : 0;
		$resetAll = !empty($_POST['reset_all']) ? $_POST['reset_all'] : 0;
		$resetAllNew = !empty($_POST['reset_all_new']) ? $_POST['reset_all_new'] : 0;

		if (!empty($userid))
		{
			$userid = battle_UserId($userid);
			loadMemberData(array($userid),false, 'normal');
			$context['battle_userid'] = ';thename=' . $userid;
			$context['battle_userlink'] = '<a href="' . $scripturl . '?action=profile;u=' . $userid . '">' . $user_profile[$userid]['real_name'] . '</a>';
			$exp = !empty($user_profile[$userid]['exp']) ? (int)$user_profile[$userid]['exp'] : 0;
			$max_exp = !empty($user_profile[$userid]['max_exp']) ? (int)$user_profile[$userid]['max_exp'] : 0;
		}

		// Reset this user to default stats?
		if ($defaults > 0)
		{
			battle_defaults($userid);
			updateMemberData($userid, array('is_dead' => 0));
			$smcFunc['db_query']('', "
				DELETE FROM {db_prefix}battle_graveyard
				WHERE id_memdef = {int:warrior}",
				array('warrior' => $userid)
			);
		}
		elseif ($resetAll > 0)
		{
			@ini_set('memory_limit', '128M');
			if ($hp > 0)
			{
				updateMemberData(null, array('is_dead' => 0));
				$smcFunc['db_query']('', "
					DELETE FROM {db_prefix}battle_graveyard
					WHERE id_memdef = {int:warrior}",
					array('warrior' => $userid)
				);
			}
			else
				updateMemberData(null, array('is_dead' => 1));

			updateMemberData(null, array(
				'stamina' => $stam,
				'energy' => $energy,
				'max_energy' => $max_energy,
				'max_stamina' => $max_stam,
				'max_def' => $max_def,
				'max_atk' => $max_atk,
				'exp' => $exp,
				'max_exp' => $max_exp,
				'level' => $level,
				'hp' => $hp,
				'max_hp' => $max_hp,
				'def' => $def,
				$currency => $cash,
				'atk' => $atk
				)
			);

		}
		elseif ($resetAllNew > 0)
		{
			@ini_set('memory_limit', '128M');
			$membersData = array();

			$request = $smcFunc['db_query']('','
				SELECT id_member, hp, ' . $currency . ', max_hp, atk, max_atk, def, max_def, energy, max_energy, stamina, max_stamina,
				exp, max_exp, level, bpm, is_dead, stat_point, mem_slays, mon_slays, battle_only_buddies_shout
				FROM {db_prefix}members
				WHERE id_member >= {int:member}
				ORDER BY id_member ASC',
				array('member' => 1)
			);

			while ($row = $smcFunc['db_fetch_assoc']($request))
			{
			    $max_exp = !empty($row['max_exp']) ? $row['max_exp'] : 0;

			    if (empty($row['level']) && empty($row['exp']) && empty($row['max_exp']))
			    {
			        $membersData[$row['id_member']] = array(
			            $currency => !empty($cash) ? $cash : 0,
			            'hp' => !empty($hp) ? $hp : 0,
			            'max_hp' => !empty($max_hp) ? $max_hp : 0,
			            'atk' => !empty($atk) ? $atk : 0,
			            'max_atk' => !empty($max_atk) ? $max_atk : 0,
			            'def' => !empty($def) ? $def : 0,
			            'max_def' => !empty($max_def) ? $max_def : 0,
			            'energy' => !empty($energy) ? $energy : 0,
			            'max_energy' => !empty($max_energy) ? $max_energy : 0,
			            'stamina' => !empty($stam) ? $stam : 0,
			            'max_stamina' => !empty($max_stam) ? $max_stam : 0,
			            'level' => !empty($level) ? $level : 0,
			            'exp' => !empty($exp) ? $exp : 0,
						'battle_points' => 0
			        );
			    }
			    elseif (empty($row['max_hp']) && empty($row['hp']))
			        $membersData[$row['id_member']] = array('hp' => 100, 'max_hp' => 100, 'battle_points' => 0);
			}

			$smcFunc['db_free_result']($request);

			foreach ($membersData as $member => $data)
			    updateMemberData($member, $data);
			$currency = !empty($modSettings['bcash']) ? $modSettings['bcash'] : 'gold';
			$tender = $smcFunc['db_list_columns']('{db_prefix}members', 'detail');
			if (!empty($tender[$currency])) {
				if (stripos($tender[$currency]['type'], 'int') !== FALSE) {
					$smcFunc['db_change_column']('{db_prefix}members',
						$currency,
						array(
							'name' => $currency,
							'type' => 'bigint',
							'size' => 11,
							'default' => $cash,
							'unsigned' => true,
							'null' => false,
						),
						array(),
						false
					);
				}
				elseif (stripos($tender[$currency]['type'], 'text') !== FALSE) {
					$type = str_ireplace('tiny', '', $tender[$currency]['type']);
					$smcFunc['db_change_column']('{db_prefix}members',
						$currency,
						array(
							'name' => $currency,
							'type' => $type,
							'default' => strval($cash),
							'unsigned' => true,
							'null' => false,
						),
						array(),
						false
					);
				}
				elseif (stripos($tender[$currency]['type'], 'varchar') !== FALSE) {
					$size = !empty($tender[$currency]['size']) ? intval($tender[$currency]['size']) : 255;
					$size = $size < 255 ? 255 : $size;
					$smcFunc['db_change_column']('{db_prefix}members',
						$currency,
						array(
							'name' => $currency,
							'type' => 'varchar',
							'size' => $size,
							'default' => strval($cash),
							'unsigned' => true,
							'null' => false,
						),
						array(),
						false
					);
				}
			}
			else {
				$smcFunc['db_add_column']('{db_prefix}members',
					array(
						'name' => $currency,
						'type' => 'bigint',
						'size' => 11,
						'default' => $cash,
						'unsigned' => true,
						'null' => false,
						),
					array(),
					false
				);
			}
			$updateTables = array(
				'members' => array(
					'lastupdate' => array(
					        'type' => 'int',
					        'size' => 11,
					        'unsigned' => true,
					        'null' => false,
					        'default' => time(),
					),
					'atk' => array(
					        'type' => 'int',
					        'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $atk,
					),
					'max_atk' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $max_atk,
					),
					'def' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $def,
					),
					'max_def' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $max_def,
					),
					'energy' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $energy,
					),
					'max_energy' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $max_energy,
					),
					'stamina' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $stam,
					),
					'max_stamina' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $max_stam,
					),
					'hp' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $hp,
					),
					'max_hp' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $max_hp,
					),
					'exp' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $exp,
					),
					'level' => array(
						'type' => 'int',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => $level,
					),
					'battle_points' => array(
						'type' => 'bigint',
						'size' => 11,
						'unsigned' => true,
						'null' => false,
						'default' => 0,
					),
				),
			);

			foreach ($updateTables as $table => $data)
			{
				foreach ($data as $key => $datum)
				{
					$smcFunc['db_change_column']('{db_prefix}' . $table,
						$key,
						$datum
					);
				}
			}
		}
		else
		{
			updateMemberData($userid, array(
				'stamina' => $stam,
				'energy' => $energy,
				'max_energy' => $max_energy,
				'max_stamina' => $max_stam,
				'max_def' => $max_def,
				'max_atk' => $max_atk,
				'exp' => $exp,
				'level' => $level,
				'hp' => $hp,
				'max_hp' => $max_hp,
				'def' => $def,
				$currency => $cash,
				'atk' => $atk
				)
			);

			if ((int)$hp > 0)
			{
				updateMemberData($userid, array('is_dead' => 0));
				$smcFunc['db_query']('', "
					DELETE FROM {db_prefix}battle_graveyard
					WHERE id_memdef = {int:warrior}",
					array('warrior' => $userid)
				);
			}
			else
			{
				$row['memdef'] = 0;
				$request = $smcFunc['db_query']('', '
					SELECT id_memdef FROM {db_prefix}battle_graveyard
					WHERE id_memdef = {int:warrior}
					LIMIT {int:limit}',
					array('warrior' => $userid, 'limit' => 1));

				$row = $smcFunc['db_fetch_assoc']($request);
				$smcFunc['db_free_result']($request);

				updateMemberData($userid, array('is_dead' => 1));
				if ((int)$row['id_memdef'] != $userid)
					$smcFunc['db_insert']('insert',
						'{db_prefix}battle_graveyard',
						array('id_mem' => 'int', 'id_memdef' => 'int', 'name' => 'string', 'date' => 'int'),
						array($user_info['id'], $userid, $user_profile[$userid]['real_name'], time()),
						array('id_grave')
					);
			}
		}

		foreach ($query_info as $info)
		{
			if ($info === 'gold')
				$context['battle_warriorInfo'][$userid][$info] = battle_gold($userid);
			else
				$context['battle_warriorInfo'][$userid][$info] = battle_query($userid, $info);
		}
	}
	elseif (allowedTo('view_mlist') && empty($_REQUEST['thename']))
	{
		$groups = join(',', $allowedBattle['allowed']);
		$request = $smcFunc['db_query']('', '
			SELECT COUNT(id_member) FROM {db_prefix}members
			WHERE id_group IN ({raw:groups}) OR id_group = 1',
			array('groups' => $groups));

		$row = $smcFunc['db_fetch_assoc']($request);
		$smcFunc['db_free_result']($request);
		$tempArray = array_values($row);
		$nRows = array_shift($tempArray);
		$page = $context['current_page'] * $per_page;

		$context['battle_members'] = ssi_queryMembers($query_where = 'id_member > 0 AND id_group IN ('.$groups.')', $query_where_params = array(), $query_limit = $page . ',' . $per_page, $query_order = $sort . ' ' . $order, $output_method = '');

		foreach ($context['battle_members'] as $key => $member)
		{
			$context['battle_warriors'][] = array(
				'name' => strlen($member['username']) > 50 ? substr($member['username'], 0, 47) . '...' : $member['username'],
				'id' => $member['id'],
				'href' => $member['href'],
				'stats' => $scripturl . '?action=admin;area=battle;sa=bmem;next;order=' . $order. ';sort=' . $sort . ';current_page=' . ($context['current_page']+1) . ';thename=' . $member['id'] . ';'
			);
		}

		// $context['battle_warriors'] = battle_pagination($context['battle_list'], 20);
		$context['current_pages'] = (($nRows-1) / $per_page) + 1;
		$context['battle_display'] = battle_pages($txt['battle_page'], false, $scripturl . '?action=admin;area=battle;sa=bmem;', $context['current_pages']);
	}
}

function battle_manage_upload()
{
	global $txt, $context, $sourcedir, $boarddir, $modSettings, $scripturl;

	if (!allowedTo('admin_battle'))
		redirectexit('action=battle;sa=main;home;#battle_main');

	$per_page = 30;
	$context['battle_smf_version'] = version_compare((!empty($modSettings['smfVersion']) ? substr($modSettings['smfVersion'], 0, 3) : '2.0'), '2.1', '<') ? 'v2.0' : 'v2.1';
	if ($context['battle_smf_version'] == 'v2.1')
	{
		$modSettings['cookieTime'] = 3153600;
		createToken('admin', 'post');
	}
	else
		require_once($sourcedir . '/Subs-Auth.php');

	$context['html_headers'] .= '
	<script type="text/javascript">
		function battle_images_js() {
			var imagedirSelect = document.getElementById("imagedir");
			if (imagedirSelect) {
				imagedirSelect.onchange = function() {
					localStorage.setItem("battle_images_directory", this.value);
					document.getElementById("battle_upload_form").action = "' . $scripturl . '?action=admin;area=battle;sa=image_upload;current_page=1;";
					document.getElementById("battle_upload_form").submit();
				};
				if ("battle_images_directory" in localStorage)
					imagedirSelect.value = localStorage.getItem("battle_images_directory");
			}
		}
		if (window.addEventListener)
			window.addEventListener("load", function (){
				battle_images_js();
				return false;
			});
		else
			window.attachEvent("onload", function (){
				battle_images_js();
				return false;
			});
	</script>';
	$context['battle_post_max_size'] = battle_return_bytes(ini_get('post_max_size')) / 1048576;
	$context['battle_post_max_size'] = preg_replace('/[^0-9\.]/', '', $context['battle_post_max_size']);
	$context['battle_post_max_size'] = round($context['battle_post_max_size'], 2);
	$context['battle_image_dirs'] = explode('|', $txt['battle_image_dirs']);
	list($context['battle_image_files'], $_SESSION['battle_image_files']) = array(array(), array());
	$dir = !empty($_SESSION['battle_imagedir']) && in_array($_SESSION['battle_imagedir'], array('monsters', 'campaign', 'shop')) ? $_SESSION['battle_imagedir'] : 'monsters';
	if (is_dir($boarddir . '/Battle/' . $dir)) {
		$fileList = glob($boarddir . '/Battle/' . $dir . '/*');
		foreach($fileList as $filename){
			if(is_file($filename) && basename($filename) != 'index.php' && basename($filename) != 'blank.gif'){
				$context['battle_image_files'][] =  'Battle/' . $dir . '/' . basename($filename);
				$_SESSION['battle_image_files'][] = $filename;
			}
		}
	}

	$image_files = $context['battle_image_files'];
	$context['battle_diaplay'] = array('page' => false, 'pages' => '0');
	$context['current_pages'] = ((count($context['battle_image_files'])-1) / $per_page) + 1;
	$context['battle_image_files'] = battle_pagination($image_files, $per_page);
	$context['battle_display'] = battle_pages($txt['battle_page'], false, $scripturl . '?action=admin;area=battle;sa=manage_upload;', $context['current_pages']);
	$context['sub_template'] = 'battle_images_upload';
	$context['page_title'] = $txt['battle_image_upload'];
}

function battle_images_upload()
{
	global $modSettings, $boarddir, $context;

	isAllowedTo('admin_battle');
	$dir = isset($_POST['imagedir']) ? $_POST['imagedir'] : 'monsters';
	$_SESSION['battle_imagedir'] = $dir;
	$postVar = !empty($_FILES['attachment']) ? $_FILES['attachment'] : array();
	$upload_directory = str_replace('\\', '/', $boarddir . '/Battle/' . $dir);
	$context['battle_smf_version'] = version_compare((!empty($modSettings['smfVersion']) ? substr($modSettings['smfVersion'], 0, 3) : '2.0'), '2.1', '<') ? 'v2.0' : 'v2.1';
	list($fileExists, $newname, $x) = array(0, '', 0);
	$page = !empty($_REQUEST['current_page']) ? ';current_page=' . intval($_REQUEST['current_page']) : '';

	switch($dir) {
		case 'campaign':
			list($width, $height) = array(25, 25);
			break;
		case 'shop':
			list($width, $height) = array(35, 35);
			break;
		default:
			list($width, $height) = array(120, 120);
	}
	if ($context['battle_smf_version'] == 'v2.1')
	{
		$modSettings['cookieTime'] = 3153600;
		createToken('admin', 'post');
	}

	if (empty($postVar))
		redirectexit('action=admin;area=battle;sa=manage_upload');

	foreach ($postVar['tmp_name'] as $n => $dummy)
	{
		if ($postVar['name'][$n] == '')
			continue;

		$postVar['name'][$n] = preg_replace(array('/\s/', '/\.[\.]+/', '/[^\w_\.\-]/'), array('_', '.', ''), $postVar['name'][$n]);
		$newname = trim(basename($postVar['name'][$n]));
		$target = $upload_directory;
		$target = rtrim($target, '/');

		$tmp_name = $postVar['tmp_name'][$n];

		if (mb_substr(mb_strtolower($newname), -4) !== '.jpg' && mb_substr(mb_strtolower($newname), -4) !== '.png' && mb_substr(mb_strtolower($newname), -4) !== '.gif' && mb_substr(mb_strtolower($newname), -4) !== '.jpeg')
			continue;

		if ($target != $upload_directory)
		{
			if (!file_exists($target) && !mkdir($target, 0755))
				fatal_lang_error('battle_not_writable', false, array($target));

			if (!is_writable($target) && !chmod($target, 0755))
				fatal_lang_error('battle_not_writable', false, array($target));
		}

		if (!file_exists($target . '/' . $newname))
		{
			if (empty(filesize($tmp_name)))
			{
				if (file_exists($tmp_name))
					unlink($tmp_name);
				clearstatcache();
				fatal_lang_error('battle_upload_file_size', false);
			}

			$fileExists = 0;
			$com = fopen($target . '/' . $newname, "ab");
			$in = fopen($tmp_name, "rb");
			if ($in)
			{
				// pause on every MB
				while ($buff = fread($in, 1048576))
				{
					fwrite($com, $buff);
					sleep(3);
				}
				fclose($in);
			}
			fclose($com);

			if (!file_exists($target . '/' . $newname))
				fatal_lang_error('battle_upload_file', false);

			@chmod($target . '/' . $newname, 0666);
			BattleImageResize($target . '/' . $newname, $target . '/' . $newname, $width, $height, 1);
		}
		else
		{
			$fileExists = 1;
			BattleImageResize($target . '/' . $newname, $target . '/' . $newname, $width, $height, 1);
		}
	}

	redirectexit('action=admin;area=battle;sa=manage_upload' . $page . ';#battle_upload_form');
}

function battle_images_delete()
{
	global $modSettings, $boarddir, $context;

	isAllowedTo('admin_battle');
	$dir = isset($_POST['imagedir']) ? $_POST['imagedir'] : (!empty($_SESSION['battle_imagedir']) ? $_SESSION['battle_imagedir'] : 'monsters');
	$_SESSION['battle_imagedir'] = $dir;
	$context['battle_smf_version'] = version_compare((!empty($modSettings['smfVersion']) ? substr($modSettings['smfVersion'], 0, 3) : '2.0'), '2.1', '<') ? 'v2.0' : 'v2.1';
	$x = 0;
	$page = !empty($_REQUEST['current_page']) ? ';current_page=' . intval($_REQUEST['current_page']) : '';

	if ($context['battle_smf_version'] == 'v2.1')
	{
		$modSettings['cookieTime'] = 3153600;
		createToken('admin', 'post');
	}

	foreach ($_SESSION['battle_image_files'] as $file)
	{
		if (isset($_POST['bfile' . $x]) && is_file($file)) {
			@unlink($file);
		}
		$x++;
	}

	redirectexit('action=admin;area=battle;sa=manage_upload' . $page . ';#battle_delete_form');
}

?>